# Better-hooks

A library to manage hooks with a clean and efficient interface.

Hooks can be used to add custom functionality to an application at specific points in the application's execution. They can be bound to any third party library, making it easier to extend and customize the functionality of the library without having to modify its code directly.

## Features
A clean and efficient interface for managing hooks
Context managers for automatically resetting hooks when no longer needed
Support for hook scopes, which allows hooks to be organized and managed more effectively

## Installation
You can install `better_hooks `using pip:
```bash
pip install better_hooks
```
